.. raw:: html

    <style media="screen" type="text/css">
      h1 {display:none;}
    </style>

*********
eazy-py
*********

Pythonic photometric redshift tools based on EAZY

Under heavy construction....

Documentation will be here: https://eazy-py.readthedocs.io/, though it's essentially just the module API for now.

Templates and filter files still here: https://github.com/gbrammer/eazy-photoz/.

.. note::
    Please submit any questions/comments/problems you have through the `Issues <https://github.com/gbrammer/eazy-py/issues>`_ interface.

~~~~~~~~~~~
Binder Demo
~~~~~~~~~~~
.. image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/gbrammer/eazy-py/HEAD?filepath=docs%2Fexamples%2FHDFN-demo.ipynb


~~~~~~~~~~~~~
Documentation
~~~~~~~~~~~~~
      
.. toctree::
   :maxdepth: 2

   eazy/install.rst
   eazy/filters.rst
   eazy/templates.rst
   eazy/photoz.rst
   eazy/zout_columns.rst

~~~     
API
~~~

.. toctree::
   :maxdepth: 2

   eazy/api.rst
